@@ -4,12 +4,10 @@ data(BlackJack)
 
 test_that("print.HydeNetwork works for full network",
 {
-  expect_that(print(BlackJack), 
-              not(throws_error()))
+  expect_output(print(BlackJack))
 })
 
 test_that("print.HydeNetwork works for selected nodes",
 {
-  expect_that(print(BlackJack, dealerFinalPoints, payoff, card5),
-              not(throws_error()))
+  expect_output(print(BlackJack, dealerFinalPoints, payoff, card5))
 })
\ No newline at end of file
